@@ -720,3 +720,43 @@ devfs = Devfs()
 udev = Udev()
 lvm = Lvm(LvmCommand())
 raid = Raid(MdadmCommand())
+
+class HwinfoError(Exception):
+    pass
+
+class HwinfoTimeout(HwinfoError):
+    pass
+
+class HwinfoNotExists(HwinfoError):
+    pass
+
+class Hwinfo(object):
+    """
+    Объект получения информации из hwinfo
+    """
+    command_timeout = 20
+    @property
+    def hwinfo_cmd(self):
+        return files.getProgPath("/usr/sbin/hwinfo")
+
+    def framebuffer(self):
+        """
+        Получить вывод hwinfo --framebuffer
+        """
+        return self.run("--framebuffer")
+
+    def run(self, *command):
+        if not self.hwinfo_cmd:
+            raise HwinfoNotExists()
+        try:
+            return files.process(*[self.hwinfo_cmd] + list(command),
+                           **{'timeout':self.command_timeout}).read()
+        except files.ProcessTimeout:
+            raise HwinfoTimeout()
+
+    def resolutions(self):
+        """
+        Получить допустимые разрешения фреймбуффера
+        """
+        re_modes = re.compile("^\s+Mode 0x[0-9a-f]+:\s+(\d+x\d+)\s",re.M)
+        return tuple(sorted(unique(re_modes.findall(self.framebuffer()))))
